@@ -1,9 +1,9 @@
-__version__ = "0.9.1"
-__author__ = "PyTorchLightning et al."
+__version__ = "0.9.2"
+__author__ = "Lightning-AI et al."
 __author_email__ = "name@pytorchlightning.ai"
 __license__ = "Apache-2.0"
 __copyright__ = f"Copyright (c) 2020-2022, {__author__}."
-__homepage__ = "https://github.com/PyTorchLightning/metrics"
+__homepage__ = "https://github.com/Lightning-AI/metrics"
 __docs__ = "PyTorch native Metrics"
 __docs_url__ = "https://torchmetrics.readthedocs.io/en/stable/"
 __long_doc__ = """
@@ -21,6 +21,7 @@ __all__ = [
     "__author_email__",
     "__copyright__",
     "__docs__",
+    "__docs_url__",
     "__homepage__",
     "__license__",
     "__version__",
