@@ -13,11 +13,16 @@ _PROJECT_ROOT = os.path.dirname(_PACKAGE_ROOT)
 
 from torchmetrics import functional  # noqa: E402
 from torchmetrics.aggregation import CatMetric, MaxMetric, MeanMetric, MinMetric, SumMetric  # noqa: E402
-from torchmetrics.audio import PESQ, PIT, SI_SDR, SI_SNR, SNR, STOI  # noqa: E402
+from torchmetrics.audio import (  # noqa: E402
+    PermutationInvariantTraining,
+    ScaleInvariantSignalDistortionRatio,
+    ScaleInvariantSignalNoiseRatio,
+    SignalDistortionRatio,
+    SignalNoiseRatio,
+)
 from torchmetrics.classification import (  # noqa: E402
     AUC,
     AUROC,
-    F1,
     ROC,
     Accuracy,
     AveragePrecision,
@@ -27,12 +32,17 @@ from torchmetrics.classification import (  # noqa: E402
     CalibrationError,
     CohenKappa,
     ConfusionMatrix,
-    FBeta,
+    CoverageError,
+    Dice,
+    F1Score,
+    FBetaScore,
     HammingDistance,
-    Hinge,
-    IoU,
+    HingeLoss,
+    JaccardIndex,
     KLDivergence,
-    MatthewsCorrcoef,
+    LabelRankingAveragePrecision,
+    LabelRankingLoss,
+    MatthewsCorrCoef,
     Precision,
     PrecisionRecallCurve,
     Recall,
@@ -40,8 +50,15 @@ from torchmetrics.classification import (  # noqa: E402
     StatScores,
 )
 from torchmetrics.collections import MetricCollection  # noqa: E402
-from torchmetrics.detection import MAP  # noqa: E402
-from torchmetrics.image import FID, IS, KID, LPIPS, PSNR, SSIM  # noqa: E402
+from torchmetrics.image import (  # noqa: E402
+    ErrorRelativeGlobalDimensionlessSynthesis,
+    MultiScaleStructuralSimilarityIndexMeasure,
+    PeakSignalNoiseRatio,
+    SpectralAngleMapper,
+    SpectralDistortionIndex,
+    StructuralSimilarityIndexMeasure,
+    UniversalImageQualityIndex,
+)
 from torchmetrics.metric import Metric  # noqa: E402
 from torchmetrics.regression import (  # noqa: E402
     CosineSimilarity,
@@ -50,11 +67,12 @@ from torchmetrics.regression import (  # noqa: E402
     MeanAbsolutePercentageError,
     MeanSquaredError,
     MeanSquaredLogError,
-    PearsonCorrcoef,
+    PearsonCorrCoef,
     R2Score,
-    SpearmanCorrcoef,
+    SpearmanCorrCoef,
     SymmetricMeanAbsolutePercentageError,
     TweedieDevianceScore,
+    WeightedMeanAbsolutePercentageError,
 )
 from torchmetrics.retrieval import (  # noqa: E402
     RetrievalFallOut,
@@ -63,11 +81,31 @@ from torchmetrics.retrieval import (  # noqa: E402
     RetrievalMRR,
     RetrievalNormalizedDCG,
     RetrievalPrecision,
+    RetrievalPrecisionRecallCurve,
     RetrievalRecall,
+    RetrievalRecallAtFixedPrecision,
     RetrievalRPrecision,
 )
-from torchmetrics.text import WER, BERTScore, BLEUScore, CharErrorRate, ROUGEScore, SacreBLEUScore  # noqa: E402
-from torchmetrics.wrappers import BootStrapper, MetricTracker, MultioutputWrapper  # noqa: E402
+from torchmetrics.text import (  # noqa: E402
+    BLEUScore,
+    CharErrorRate,
+    CHRFScore,
+    ExtendedEditDistance,
+    MatchErrorRate,
+    SacreBLEUScore,
+    SQuAD,
+    TranslationEditRate,
+    WordErrorRate,
+    WordInfoLost,
+    WordInfoPreserved,
+)
+from torchmetrics.wrappers import (  # noqa: E402
+    BootStrapper,
+    ClasswiseWrapper,
+    MetricTracker,
+    MinMaxMetric,
+    MultioutputWrapper,
+)
 
 __all__ = [
     "functional",
@@ -78,28 +116,32 @@ __all__ = [
     "BinnedAveragePrecision",
     "BinnedPrecisionRecallCurve",
     "BinnedRecallAtFixedPrecision",
-    "BERTScore",
     "BLEUScore",
     "BootStrapper",
     "CalibrationError",
     "CatMetric",
+    "ClasswiseWrapper",
+    "CharErrorRate",
+    "CHRFScore",
     "CohenKappa",
     "ConfusionMatrix",
     "CosineSimilarity",
+    "CoverageError",
+    "Dice",
     "TweedieDevianceScore",
+    "ErrorRelativeGlobalDimensionlessSynthesis",
     "ExplainedVariance",
-    "F1",
-    "FBeta",
-    "FID",
+    "ExtendedEditDistance",
+    "F1Score",
+    "FBetaScore",
     "HammingDistance",
-    "Hinge",
-    "IoU",
-    "IS",
-    "KID",
+    "HingeLoss",
+    "JaccardIndex",
     "KLDivergence",
-    "LPIPS",
-    "MAP",
-    "MatthewsCorrcoef",
+    "LabelRankingAveragePrecision",
+    "LabelRankingLoss",
+    "MatchErrorRate",
+    "MatthewsCorrCoef",
     "MaxMetric",
     "MeanAbsoluteError",
     "MeanAbsolutePercentageError",
@@ -109,14 +151,15 @@ __all__ = [
     "Metric",
     "MetricCollection",
     "MetricTracker",
+    "MinMaxMetric",
     "MinMetric",
     "MultioutputWrapper",
-    "PearsonCorrcoef",
-    "PESQ",
-    "PIT",
+    "MultiScaleStructuralSimilarityIndexMeasure",
+    "PearsonCorrCoef",
+    "PermutationInvariantTraining",
     "Precision",
     "PrecisionRecallCurve",
-    "PSNR",
+    "PeakSignalNoiseRatio",
     "R2Score",
     "Recall",
     "RetrievalFallOut",
@@ -127,19 +170,27 @@ __all__ = [
     "RetrievalPrecision",
     "RetrievalRecall",
     "RetrievalRPrecision",
+    "RetrievalPrecisionRecallCurve",
+    "RetrievalRecallAtFixedPrecision",
     "ROC",
-    "ROUGEScore",
     "SacreBLEUScore",
-    "SI_SDR",
-    "SI_SNR",
-    "SNR",
-    "SpearmanCorrcoef",
+    "SignalDistortionRatio",
+    "ScaleInvariantSignalDistortionRatio",
+    "ScaleInvariantSignalNoiseRatio",
+    "SignalNoiseRatio",
+    "SpearmanCorrCoef",
     "Specificity",
-    "SSIM",
+    "SpectralAngleMapper",
+    "SpectralDistortionIndex",
+    "SQuAD",
+    "StructuralSimilarityIndexMeasure",
     "StatScores",
-    "STOI",
     "SumMetric",
     "SymmetricMeanAbsolutePercentageError",
-    "WER",
-    "CharErrorRate",
+    "TranslationEditRate",
+    "UniversalImageQualityIndex",
+    "WeightedMeanAbsolutePercentageError",
+    "WordErrorRate",
+    "WordInfoLost",
+    "WordInfoPreserved",
 ]
