@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Dict, List
+from typing import Any, List
 
 import torch
 from torch import Tensor
@@ -66,7 +66,7 @@ class CalibrationError(Metric):
         self,
         n_bins: int = 15,
         norm: str = "l1",
-        **kwargs: Dict[str, Any],
+        **kwargs: Any,
     ):
 
         super().__init__(**kwargs)
