@@ -208,7 +208,7 @@ class MeanAveragePrecision(Metric):
     See the :meth:`update` method for more information about the input format to this metric.
 
     For an example on how to use this metric check the `torchmetrics examples
-    <https://github.com/PyTorchLightning/metrics/blob/master/tm_examples/detection_map.py>`_
+    <https://github.com/Lightning-AI/metrics/blob/master/tm_examples/detection_map.py>`_
 
     .. note::
         This metric is following the mAP implementation of
@@ -226,7 +226,8 @@ class MeanAveragePrecision(Metric):
             Input format of given boxes. Supported formats are ``[`xyxy`, `xywh`, `cxcywh`]``.
         iou_type:
             Type of input (either masks or bounding-boxes) used for computing IOU.
-            Supported IOU types are ``[`bboxes`, `segm`]``.
+            Supported IOU types are ``["bboxes", "segm"]``.
+            If using ``"segm"``, masks should be provided (see :meth:`update`).
         iou_thresholds:
             IoU thresholds for evaluation. If set to ``None`` it corresponds to the stepped range ``[0.5,...,0.95]``
             with step ``0.05``. Else provide a list of floats.
@@ -355,6 +356,8 @@ class MeanAveragePrecision(Metric):
                 - ``scores``: ``torch.FloatTensor`` of shape ``[num_boxes]`` containing detection scores for the boxes.
                 - ``labels``: ``torch.IntTensor`` of shape ``[num_boxes]`` containing 0-indexed detection classes
                   for the boxes.
+                - ``masks``: ``torch.bool`` of shape ``[num_boxes, image_height, image_width]`` containing boolean
+                  masks. Only required when `iou_type="segm"`.
 
             target: A list consisting of dictionaries each containing the key-values
                 (each dictionary corresponds to a single image):
@@ -364,6 +367,8 @@ class MeanAveragePrecision(Metric):
                   ``[xmin, ymin, xmax, ymax]`` in absolute image coordinates.
                 - ``labels``: ``torch.IntTensor`` of shape ``[num_boxes]`` containing 0-indexed ground truth
                    classes for the boxes.
+                - ``masks``: ``torch.bool`` of shape ``[num_boxes, image_height, image_width]`` containing boolean
+                  masks. Only required when `iou_type="segm"`.
 
         Raises:
             ValueError:
@@ -416,7 +421,8 @@ class MeanAveragePrecision(Metric):
 
         if self.iou_type == "bbox":
             boxes = _fix_empty_tensors(item["boxes"])
-            boxes = box_convert(boxes, in_fmt=self.box_format, out_fmt="xyxy")
+            if boxes.numel() > 0:
+                boxes = box_convert(boxes, in_fmt=self.box_format, out_fmt="xyxy")
             return boxes
         elif self.iou_type == "segm":
             masks = []
@@ -482,9 +488,9 @@ class MeanAveragePrecision(Metric):
     ) -> Dict[str, Any]:
         """Some GT but no predictions."""
         # GTs
-        gt = gt[gt_label_mask]
+        gt = [gt[i] for i in gt_label_mask]
         nb_gt = len(gt)
-        areas = box_area(gt)
+        areas = compute_area(gt, iou_type=self.iou_type).to(self.device)
         ignore_area = (areas < area_range[0]) | (areas > area_range[1])
         gt_ignore, _ = torch.sort(ignore_area.to(torch.uint8))
         gt_ignore = gt_ignore.to(torch.bool)
