@@ -73,16 +73,15 @@ def _precision_recall_curve_update(
         preds: Predicted tensor
         target: Ground truth tensor
         num_classes: integer with number of classes for multi-label and multiclass problems.
-            Should be set to ``None`` for binary problems
+            Should be set to ``None`` for binary problems.
         pos_label: integer determining the positive class. Default is ``None``
-            which for binary problem is translate to 1. For multiclass problems
+            which for binary problem is translated to 1. For multiclass problems
             this argument should not be set as we iteratively change it in the
             range [0,num_classes-1]
     """
 
     if len(preds.shape) == len(target.shape):
         if pos_label is None:
-            rank_zero_warn("`pos_label` automatically set 1.")
             pos_label = 1
         if num_classes is not None and num_classes != 1:
             # multilabel problem
@@ -170,7 +169,7 @@ def _precision_recall_curve_compute_multi_class(
         preds: Predicted tensor
         target: Ground truth tensor
         num_classes: integer with number of classes for multi-label and multiclass problems.
-            Should be set to ``None`` for binary problems
+            Should be set to ``None`` for binary problems.
         sample_weights: sample weights for each data point
     """
 
@@ -214,11 +213,11 @@ def _precision_recall_curve_compute(
         preds: Predicted tensor
         target: Ground truth tensor
         num_classes: integer with number of classes for multi-label and multiclass problems.
-            Should be set to ``None`` for binary problems
+            Should be set to ``None`` for binary problems.
         pos_label: integer determining the positive class. Default is ``None``
-            which for binary problem is translate to 1. For multiclass problems
+            which for binary problem is translated to 1. For multiclass problems
             this argument should not be set as we iteratively change it in the
-            range [0,num_classes-1]
+            range ``[0,num_classes-1]``
         sample_weights: sample weights for each data point
 
     Example:
@@ -244,7 +243,7 @@ def _precision_recall_curve_compute(
         >>> num_classes = 5
         >>> preds, target, num_classes, pos_label = _precision_recall_curve_update(preds, target, num_classes)
         >>> precision, recall, thresholds = _precision_recall_curve_compute(preds, target, num_classes)
-        >>> precision   # doctest: +NORMALIZE_WHITESPACE
+        >>> precision
         [tensor([1., 1.]), tensor([1., 1.]), tensor([0.2500, 0.0000, 1.0000]),
          tensor([0.2500, 0.0000, 1.0000]), tensor([0., 1.])]
         >>> recall
@@ -274,23 +273,22 @@ def precision_recall_curve(
         preds: predictions from model (probabilities)
         target: ground truth labels
         num_classes: integer with number of classes for multi-label and multiclass problems.
-            Should be set to ``None`` for binary problems
-        pos_label: integer determining the positive class. Default is ``None``
-            which for binary problem is translate to 1. For multiclass problems
-            this argument should not be set as we iteratively change it in the
-            range [0,num_classes-1]
+            Should be set to ``None`` for binary problems.
+        pos_label: integer determining the positive class. Default is ``None`` which for binary problem is translated
+            to 1. For multiclass problems this argument should not be set as we iteratively change it in the
+            range ``[0, num_classes-1]``
         sample_weights: sample weights for each data point
 
     Returns:
         3-element tuple containing
 
         precision:
-            tensor where element i is the precision of predictions with
-            score >= thresholds[i] and the last element is 1.
+            tensor where element ``i`` is the precision of predictions with
+            ``score >= thresholds[i]`` and the last element is 1.
             If multiclass, this is a list of such tensors, one for each class.
         recall:
-            tensor where element i is the recall of predictions with
-            score >= thresholds[i] and the last element is 0.
+            tensor where element ``i`` is the recall of predictions with
+            ``score >= thresholds[i]`` and the last element is 0.
             If multiclass, this is a list of such tensors, one for each class.
         thresholds:
             Thresholds used for computing precision/recall scores
@@ -300,8 +298,7 @@ def precision_recall_curve(
             If ``preds`` and ``target`` don't have the same number of dimensions,
             or one additional dimension for ``preds``.
         ValueError:
-            If the number of classes deduced from ``preds`` is not the same as the
-            ``num_classes`` provided.
+            If the number of classes deduced from ``preds`` is not the same as the ``num_classes`` provided.
 
     Example (binary case):
         >>> from torchmetrics.functional import precision_recall_curve
@@ -322,7 +319,7 @@ def precision_recall_curve(
         ...                      [0.05, 0.05, 0.05, 0.75, 0.05]])
         >>> target = torch.tensor([0, 1, 3, 2])
         >>> precision, recall, thresholds = precision_recall_curve(pred, target, num_classes=5)
-        >>> precision   # doctest: +NORMALIZE_WHITESPACE
+        >>> precision
         [tensor([1., 1.]), tensor([1., 1.]), tensor([0.2500, 0.0000, 1.0000]),
          tensor([0.2500, 0.0000, 1.0000]), tensor([0., 1.])]
         >>> recall
