@@ -24,13 +24,14 @@ def _symmetric_mean_absolute_percentage_error_update(
     target: Tensor,
     epsilon: float = 1.17e-06,
 ) -> Tuple[Tensor, int]:
-    """Updates and returns variables required to compute Symmetric Mean Absolute Percentage Error. Checks for same
-    shape of input tensors.
+    """Updates and returns variables required to compute Symmetric Mean Absolute Percentage Error.
+
+    Checks for same shape of input tensors.
 
     Args:
         preds: Predicted tensor
         target: Ground truth tensor
-        epsilon: Avoids ZeroDivisionError.
+        epsilon: Avoids ``ZeroDivisionError``.
     """
 
     _check_same_shape(preds, target)
@@ -50,7 +51,7 @@ def _symmetric_mean_absolute_percentage_error_compute(sum_abs_per_error: Tensor,
 
     Args:
         sum_abs_per_error: Sum of values of symmetric absolute percentage errors over all observations
-            (symmetric absolute percentage error = 2 * |target - prediction| / (target + prediction))
+            ``(symmetric absolute percentage error = 2 * |target - prediction| / (target + prediction))``
         num_obs: Number of predictions or observations
 
     Example:
@@ -68,7 +69,7 @@ def symmetric_mean_absolute_percentage_error(preds: Tensor, target: Tensor) -> T
     r"""
     Computes symmetric mean absolute percentage error (SMAPE_):
 
-    .. math:: \text{SMAPE} = \frac{2}{n}\sum_1^n\frac{max(|   y_i - \hat{y_i} |}{| y_i | + | \hat{y_i} |, \epsilon)}
+    .. math:: \text{SMAPE} = \frac{2}{n}\sum_1^n\frac{|   y_i - \hat{y_i} |}{max(| y_i | + | \hat{y_i} |, \epsilon)}
 
     Where :math:`y` is a tensor of target values, and :math:`\hat{y}` is a tensor of predictions.
 
