@@ -27,6 +27,7 @@ def _wip_update(
     Args:
         preds: Transcription(s) to score as a string or list of strings
         target: Reference(s) for each speech input as a string or list of strings
+
     Returns:
         Number of edit operations to get from the reference to the prediction, summed over all samples
         Number of words overall references
@@ -58,6 +59,7 @@ def _wip_compute(errors: Tensor, target_total: Tensor, preds_total: Tensor) -> T
         errors: Number of edit operations to get from the reference to the prediction, summed over all samples
         target_total: Number of words overall references
         preds_total: Number of words overall prediction
+
     Returns:
         Word Information Perserved score
     """
@@ -73,10 +75,8 @@ def word_information_preserved(
     better the performance of the ASR system with a Word Information preserved rate of 0 being a perfect score.
 
     Args:
-        preds:
-            Transcription(s) to score as a string or list of strings
-        total:
-            Reference(s) for each speech input as a string or list of strings
+        preds: Transcription(s) to score as a string or list of strings
+        target: Reference(s) for each speech input as a string or list of strings
 
     Returns:
         Word Information preserved rate
