@@ -11,7 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Dict, List
+from typing import Any, List
 
 import torch
 from torch import Tensor
@@ -60,7 +60,7 @@ class CosineSimilarity(Metric):
     def __init__(
         self,
         reduction: Literal["mean", "sum", "none", None] = "sum",
-        **kwargs: Dict[str, Any],
+        **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
         allowed_reduction = ("sum", "mean", "none", None)
