@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Any, Dict, List, Union
+from typing import Any, List, Union
 
 from torch import Tensor, tensor
 
@@ -59,7 +59,7 @@ class WordInfoPreserved(Metric):
 
     def __init__(
         self,
-        **kwargs: Dict[str, Any],
+        **kwargs: Any,
     ):
         super().__init__(**kwargs)
         self.add_state("errors", tensor(0.0), dist_reduce_fx="sum")
