@@ -23,3 +23,18 @@ def _safe_matmul(x: Tensor, y: Tensor) -> Tensor:
     if x.dtype == torch.float16 or y.dtype == torch.float16:
         return (x.float() @ y.T.float()).half()
     return x @ y.T
+
+
+def _safe_xlogy(x: Tensor, y: Tensor) -> Tensor:
+    """Computes x * log(y). Returns 0 if x=0.
+
+    Example:
+        >>> import torch
+        >>> x = torch.zeros(1)
+        >>> _safe_xlogy(x, 1/x)
+        tensor([0.])
+
+    """
+    res = x * torch.log(y)
+    res[x == 0] = 0.0
+    return res
