@@ -16,6 +16,20 @@ from typing import Any, Callable, Dict, List, Mapping, Optional, Sequence, Union
 import torch
 from torch import Tensor, tensor
 
+from torchmetrics.utilities.imports import _TORCH_GREATER_EQUAL_1_6, _TORCH_GREATER_EQUAL_1_7, _TORCH_GREATER_EQUAL_1_8
+
+if _TORCH_GREATER_EQUAL_1_8:
+    deterministic = torch.are_deterministic_algorithms_enabled
+elif _TORCH_GREATER_EQUAL_1_7:
+    deterministic = torch.is_deterministic
+elif _TORCH_GREATER_EQUAL_1_6:
+    deterministic = torch._is_deterministic
+else:
+
+    def deterministic() -> bool:
+        return True
+
+
 METRIC_EPS = 1e-6
 
 
@@ -157,10 +171,10 @@ def apply_to_collection(
         data: the collection to apply the function to
         dtype: the given function will be applied to all elements of this dtype
         function: the function to apply
-        *args: positional arguments (will be forwarded to calls of ``function``)
+        *args: positional arguments (will be forwarded to call of ``function``)
         wrong_dtype: the given function won't be applied if this type is specified and the given collections is of
             the :attr:`wrong_type` even if it is of type :attr`dtype`
-        **kwargs: keyword arguments (will be forwarded to calls of ``function``)
+        **kwargs: keyword arguments (will be forwarded to call of ``function``)
 
     Returns:
         the resulting collection
@@ -194,11 +208,10 @@ def apply_to_collection(
 
 
 def get_group_indexes(indexes: Tensor) -> List[Tensor]:
-    """Given an integer ``torch.Tensor`` ``indexes``, return a ``torch.Tensor`` of indexes for each different value
-    in ``indexes``.
+    """Given an integer ``indexes``, return indexes for each different value in ``indexes``.
 
     Args:
-        indexes: a ``torch.Tensor``
+        indexes:
 
     Return:
         A list of integer ``torch.Tensor``s
@@ -240,7 +253,7 @@ def _bincount(x: Tensor, minlength: Optional[int] = None) -> Tensor:
     Returns:
         Number of occurrences for each unique element in x
     """
-    if x.is_cuda and torch.are_deterministic_algorithms_enabled():
+    if x.is_cuda and deterministic():
         if minlength is None:
             minlength = len(torch.unique(x))
         output = torch.zeros(minlength, device=x.device, dtype=torch.long)
@@ -249,3 +262,10 @@ def _bincount(x: Tensor, minlength: Optional[int] = None) -> Tensor:
         return output
     else:
         return torch.bincount(x, minlength=minlength)
+
+
+def allclose(tensor1: Tensor, tensor2: Tensor) -> bool:
+    """Wrapper of torch.allclose that is robust towards dtype difference."""
+    if tensor1.dtype != tensor2.dtype:
+        tensor2 = tensor2.to(dtype=tensor1.dtype)
+    return torch.allclose(tensor1, tensor2)
